//******************************************************************************
// JsrDir.java:    Sorted directory listing.
//                 If args[0] not null, filename must contain args[0]
//******************************************************************************
import java.io.*; 
import java.util.*;

/**
  * Read directory.
  */
  
public class JsrDir 
{ 
  static final String COPYRIGHT = 
      "Copyright 2001, JSR Systems.  See: www.Jsrsys.com/copyright.";
  String       lookDir  = "";
  String       filter   = "";
  JsrSysout     sysout  = new JsrSysout();
  JsrSortString sortDir = new JsrSortString();
  JsrUtil             u = new JsrUtil();
  File          listDir;
  File          thisFile;
  int            lenDir;
  int          firstLen;
  String[]    listFiles;
  String[]    listTypes;
  Date        thisDate;
  String       newDate;
  String      fileSepChar;

  
    // JsrDir Class Constructor
    //--------------------------------------------------------------------------
    public JsrDir()
    {
        fileSepChar = File.separator;
    }
    
/** directory to search <BR>
  * filter on file name.
  */
    public JsrDir(String dirName, String fileFilter)
    {
        setDir(dirName);
        filter  = fileFilter.toLowerCase();
        fileSepChar = File.separator;

    }
    
    //--------------------------------------------------------------------------
    public static void main(String argv[])
    {
        JsrDir JsrDir = new JsrDir();
        JsrDir.run(argv);
    }
    
/**
  * returns System dependent file separator Character
  */

    public String getFileSepChar()
    {
        return fileSepChar;
    }
    
    public void run(String parm[])
    {
      sysout.display("File.separator="+fileSepChar);
      sysout.display("JsrDir--"+COPYRIGHT);
      sysout.display("JsrDir--usage: JsrDir <filter> <full path name>");
      lookDir = System.getProperty("user.dir");
      sysout.display("Current User Directory: " + lookDir);
      if (parm.length >=1 )
      {
         filter = parm[0].toLowerCase();
         sysout.display("          Filtering on: " + filter);
      }
      
      if (parm.length >= 2)
      {
         lookDir = parm[1];
         sysout.display("      Search Directory: " + lookDir);
      }
      this.getSortedDir();
      this.getDirTypes();
      sysout.display("             Directory: " + lookDir
                  + " (# entries=" + firstLen    + ")");
      for (int i=0; i < lenDir; i++)
      {   
         sysout.display(listTypes[i]+" "+listFiles[i]);
      }
      sysout.display("             Directory: " + lookDir
               +" (# selected=" + lenDir +")");
      sysout.display("JsrDir--"+COPYRIGHT);
    }
 //--------------------------------------------------------------------------
    
    public void setFilter(String newFilter)
    {
        filter = newFilter.toLowerCase();
    }
    
/**
  * &quot;*current*&quot;=search current directory
  */
    public void setDir(String newDir)
    {
        if  (newDir.equals("*current*"))
            lookDir = System.getProperty("user.dir");
        else
            lookDir = newDir;
    }
    
/** returns sorted array of filtered file names.
  *
  */
    public String[] getSortedDir()
    {
      if (lookDir.length() == 0) lookDir = System.getProperty("user.dir");
         // default to current directory and no filter if constructor is null.
      listDir = new File(lookDir);   // get directory
      //sysout.display("lookDir="+lookDir+" listDir="+listDir);
      //thisDir = listDir.getAbsolutePath();
      //listDir = new File(thisDir);        // listDir is now full path
      //thisDir = listDir.getParent();      // thisDir is string of just DirName
      listFiles = listDir.list();
      lenDir = listFiles.length;
      firstLen = lenDir;
      if (filter.length() > 0)
      {
         String[] temp1 = new String[lenDir];
         int i = 0;
         int j = 0;
         int index = 0;
         for (i=0; i < lenDir; i++)
         {
            index = listFiles[i].toLowerCase().indexOf(filter);
            if (index >= 0 )
            {
                temp1 [j] = listFiles[i];
                j++;
            }
            //sysout.display(listFiles[i]+" Match="+j+" index="+index+" filter="+filter);
         }
         listFiles = new String[j];
         lenDir    = j;
         for (i=0; i < j; i++) listFiles[i] = temp1[i];
         //sysout.display("j="+j+"/listFiles="+listFiles.length);
      }
      if (listFiles.length > 1)
          try {sortDir.sort(listFiles);} 
              catch (Exception Sort) {sysout.display("Sort Error");}
              
      return listFiles;
    }
    
/** returns array of entry types (File:, Dir:).
  */
    public String[] getDirTypes()
    {
      listTypes = new String[lenDir];
      for (int i=0; i < lenDir; i++)
      {   
           thisFile = new File(lookDir+fileSepChar+listFiles[i]);
           //                  use     fileSepChar  so will work on Linux and Windows.
           if (thisFile.isFile()) 
           { 
               long intCount = thisFile.length(); 
               thisDate = new Date(thisFile.lastModified());
               newDate = thisDate.toString();
               newDate = newDate.substring(24)
                        +newDate.substring(03,20)
                        +newDate.substring(00,03);
               listTypes[i]    ="File: "+newDate
                               +u.padLeft(intCount,10)
                               ;
           }             
           else
           if (thisFile.isDirectory())   
               listTypes[i]    =" Dir:                                  ";
           else
               listTypes[i]    ="???:                                   ";
      }
               
      return listTypes;
    }

} // end of Class
